#!/bin/sh

function control_c () {
    echo "*** INTERRUPTED ***"
    exit 1
}

trap control_c SIGINT

function run_group () {
    name=$1
    shift
    list=$1
    shift
    logfile=$1
    shift
    prefix=$1
    shift
    type=$1
    shift
    args=$@

    echo "Running $name (results in $logfile)..."
    rm -f $logfile
    for f in `cat $list`; do
        querystr=""
        echo "  $f "
       
        echo "####################################################" >> $logfile
        echo $f >> $logfile
        ulimit -s unlimited -v 8000000
        runlim -s 8000000 $args $prefix/${f} ${querystr} >> $logfile 2>&1
    done
}

KRATOS4BIP="bin/kratos4bip"
BIPCHECKER="bin/bipchecker2"
NUXMV="bin/nuXmv"
DFINDER_PATH=""
DFINDER_SCRIPT="./bin/dfinder.sh"

if [ ! -d "${DFINDER_PATH}" ]; then
    echo "Set in DFINDER_PATH the path to your version of DFinder"
    exit 1
fi


################################################################################
# NUXMV
################################################################################
benchmarks=models/nuxmv_list.txt
run_group "IC3IA" $benchmarks "results/ic3abs.txt" "models/SMV" "" ${NUXMV} -source scripts/ic3abs.cmd
run_group "BMC" $benchmarks "results/bmc.txt" "models/SMV" "" ${NUXMV} -source scripts/bmc.cmd


################################################################################
# KRATOS4BIP
################################################################################
benchmarks=models/bip2.txt
run_group "KRATOS4BIP_DFS_SEQ" $benchmarks "results/kratos4bip_dfs_seq.txt" "models/BIP2" "" ${KRATOS4BIP} --node_expansion_strategy=DFS --enable_POR=false --interaction_execution=Serialization --verbosity_level=0
run_group "KRATOS4BIP_DFS_CONC" $benchmarks "results/kratos4bip_dfs_conc.txt" "models/BIP2" "" ${KRATOS4BIP} --node_expansion_strategy=DFS --enable_POR=false --interaction_execution=Concurrent --verbosity_level=0
run_group "KRATOS4BIP_DFS_SEQ_POR" $benchmarks "results/kratos4bip_dfs_seq_por.txt" "models/BIP2" "" ${KRATOS4BIP} --node_expansion_strategy=DFS --enable_POR=false --interaction_execution=Serialization --verbosity_level=0
run_group "KRATOS4BIP_DFS_CONC_POR" $benchmarks "results/kratos4bip_dfs_conc_por.txt" "models/BIP2" "" ${KRATOS4BIP} --node_expansion_strategy=DFS --enable_POR=true --enable_sleep_set=true --interaction_execution=Concurrent --verbosity_level=0

################################################################################
# BIPCHECKER2
################################################################################
run_group "BIPCHECKER2" $benchmarks "results/bipchecker2.txt" "models/BIP2" "" ${KRATOS4BIP} --node_expansion_strategy=DFS --enable_POR=false --verbosity_level=0
run_group "BIPCHECKER2_POR" $benchmarks "results/bipchecker2_por.txt" "models/BIP2" "" ${KRATOS4BIP} --node_expansion_strategy=DFS --enable_POR=true --enable_sleep_set=true --verbosity_level=0


################################################################################
# DFINDER
################################################################################
benchmarks=models/bip.txt
current=`pwd`
modelpath="${current}/models/BIP"
run_group "DFINDER_PM" $benchmarks "results/dfinder_pm.txt" "${modelpath}" "" ${DFINDER_SCRIPT} ${DFINDER_PATH} "/tmp" "pm"
run_group "DFINDER_FP" $benchmarks "results/dfinder_fp.txt" "${modelpath}" "" ${DFINDER_SCRIPT} ${DFINDER_PATH} "/tmp" "fp"
run_group "DFINDER_LINEAR" $benchmarks "results/dfinder_linear.txt" "${modelpath}" "" ${DFINDER_SCRIPT} ${DFINDER_PATH} "/tmp" "linear"


